@@ -1,5 +1,18 @@
 variants_compile <-
 function(omim,clinvar,uniprot,localPDB.path = paste(getwd(),"localPDB",sep="/")){
+   
+   ## function, extract the gene and p.change
+   p.change <- function(x){
+      # x = "NM_001173990.2(TMEM216):c.218G>T (p.Arg73Leu)"
+        x.split = unlist(strsplit(x,":|\\(|\\)"))
+        if( length(x.split) == 5){
+           x.trim = paste(x.split[1], x.split[5],sep=":")
+           }else{
+              x.trim = x
+        } 
+        return(x.trim)
+   }
+   
     clinvarDB <- read.delim(gzfile(paste(localPDB.path,"variant_summary.txt.gz",sep="/"))) 
     var.omim <- setdiff(omim[,"clinvarAccessions"],clinvar$RCVaccession) 
     omim.add <- clinvar.add <- uniprot.add <- c()   
@@ -23,7 +36,7 @@ function(omim,clinvar,uniprot,localPDB.path = paste(getwd(),"localPDB",sep="/"))
       
 # compile uniprot variants into clinvar
     var.uniprot <- paste(uniprot[,1],unlist(lapply(uniprot[,4],str_trim)),sep=":")
-    var.clinvar <- paste(clinvar[,"GeneSymbol"], unlist(lapply(as.character(clinvar[,"HGVS.p.."]), function(x) unlist(strsplit(x,":"))[2])),sep=":")
+    var.clinvar <- unlist(lapply(as.character(clinvar[,"Name"]),  p.change))
     var.uniprot.1 <- setdiff(var.uniprot,var.clinvar)
     uniprot.add <- uniprot[is.element(var.uniprot,var.uniprot.1),]
 
@@ -49,20 +62,20 @@ function(omim,clinvar,uniprot,localPDB.path = paste(getwd(),"localPDB",sep="/"))
     var.add <- matrix(,nrow= sum(nrow.omim.add, nrow(clinvar.add), nrow.uniprot.add),ncol=ncol(var2pheno))
     colnames(var.add) <- colnames(var2pheno)
     if(!is.null(clinvar.add)) 
-        var.add[1:nrow(clinvar.add),1:29] <- as.matrix(clinvar.add)
+        var.add[1:nrow(clinvar.add),1:ncol(clinvar.add)] <- as.matrix(clinvar.add)
     if(nrow.omim.add > 1 ) {
-        var.add[sum(nrow(clinvar.add),1):sum(nrow(clinvar.add),nrow.omim.add),c("GeneSymbol","Chromosome","Cytogenetic","omim.phenotype","OtherIDs","Mutation.add","RS...dbSNP.")] <- 
+        var.add[sum(nrow(clinvar.add),1):sum(nrow(clinvar.add),nrow.omim.add),c("GeneSymbol","Chromosome","Cytogenetic","PhenotypeList","OtherIDs","Mutation.add","RS...dbSNP.")] <- 
                  as.matrix(omim.add[,c("Approved.Symbol","Chromosome","cytoLocation","Phenotype","variants.ID","mutations","dbSNPs")])
         }else if(nrow.omim.add == 1){
-             var.add[sum(nrow(clinvar.add),1):sum(nrow(clinvar.add),nrow.omim.add),c("GeneSymbol","Chromosome","Cytogenetic","omim.phenotype","OtherIDs","Mutation.add","RS...dbSNP.")] <- 
+             var.add[sum(nrow(clinvar.add),1):sum(nrow(clinvar.add),nrow.omim.add),c("GeneSymbol","Chromosome","Cytogenetic","PhenotypeList","OtherIDs","Mutation.add","RS...dbSNP.")] <- 
                    as.matrix(omim.add[c("Approved.Symbol","Chromosome","cytoLocation","Phenotype","variants.ID","mutations","dbSNPs")])        
     }    
                  
     if(nrow.uniprot.add > 1) { 
-        var.add[sum(nrow(clinvar.add),nrow.omim.add,1):nrow(var.add),c("GeneSymbol","omim.phenotype","HGVS.p..","RS...dbSNP.","ClinicalSignificance")] <- 
+        var.add[sum(nrow(clinvar.add),nrow.omim.add,1):nrow(var.add),c("GeneSymbol","PhenotypeList","Name","RS...dbSNP.","ClinicalSignificance")] <- 
                  as.matrix(uniprot.add[,c("GeneSymbol","DiseaseName","AA.change","dbSNP","type")])
          }else if(nrow.uniprot.add == 1) { 
-        var.add[sum(nrow(clinvar.add),nrow.omim.add,1):nrow(var.add),c("GeneSymbol","omim.phenotype","HGVS.p..","RS...dbSNP.","ClinicalSignificance")] <- 
+        var.add[sum(nrow(clinvar.add),nrow.omim.add,1):nrow(var.add),c("GeneSymbol","PhenotypeList","Name","RS...dbSNP.","ClinicalSignificance")] <- 
                  as.matrix(uniprot.add[c("GeneSymbol","DiseaseName","AA.change","dbSNP","type")]) 
     }
     var2pheno <- rbind(var2pheno,var.add)
